plugins/kolab_addressbook

Aleksander Machniak machniak at kolabsys.com
Wed May 8 14:23:51 CEST 2013


 plugins/kolab_addressbook/lib/rcube_kolab_contacts.php |    5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

New commits:
commit f591f88699c8a90407aa9bd85129c03aa47b22f0
Author: Aleksander Machniak <machniak at kolabsys.com>
Date:   Wed May 8 14:22:18 2013 +0200

    Fix "incompat. declaration" error - revert part of 27e57c73352e1966918cdfe567c32c5a4844be82

diff --git a/plugins/kolab_addressbook/lib/rcube_kolab_contacts.php b/plugins/kolab_addressbook/lib/rcube_kolab_contacts.php
index 35312d9..5437056 100644
--- a/plugins/kolab_addressbook/lib/rcube_kolab_contacts.php
+++ b/plugins/kolab_addressbook/lib/rcube_kolab_contacts.php
@@ -245,11 +245,12 @@ class rcube_kolab_contacts extends rcube_addressbook
     /**
      * List the current set of contact records
      *
      * @param  int    Only return this number of records, use negative values for tail
      *
      * @return array  Indexed list of contact records, each a hash array
      */
-    public function list_records($subset = 0)
+    public function list_records($cols = null, $subset = 0)
     {
         $this->result = new rcube_result_set(0, ($this->list_page-1) * $this->page_size);;
 
@@ -245,11 +245,12 @@ class rcube_kolab_contacts extends rcube_addressbook
      * List the current set of contact records
      *
-     * @param  int    Only return this number of records, use negative values for tail
+     * @param array List of cols to show
+     * @param  int  Only return this number of records, use negative values for tail
      *
      * @return array  Indexed list of contact records, each a hash array





More information about the commits mailing list